import request from '@/utils/request'

// 查询疫情登记用户列表
export function listYiqing(query) {
  return request({
    url: '/yiqing/yiqing/list',
    method: 'get',
    params: query
  })
}

// 查询疫情登记问题列表
export function getQueList() {
  return request({
    url: '/api/yq/list',
    method: 'get'
  })
}

// 保存提交
export function save(data) {
  return request({
    url: '/api/yq/save',
    method: 'post',
    data: data
  })
}

// 查询疫情登记用户详细
export function getYiqing(id) {
  return request({
    url: '/yiqing/yiqing/' + id,
    method: 'get'
  })
}

// 新增疫情登记用户
export function addYiqing(data) {
  return request({
    url: '/yiqing/yiqing',
    method: 'post',
    data: data
  })
}

// 修改疫情登记用户
export function updateYiqing(data) {
  return request({
    url: '/yiqing/yiqing',
    method: 'put',
    data: data
  })
}

// 删除疫情登记用户
export function delYiqing(id) {
  return request({
    url: '/yiqing/yiqing/' + id,
    method: 'delete'
  })
}

// 导出疫情登记用户
export function exportYiqing(query) {
  return request({
    url: '/yiqing/yiqing/export',
    method: 'get',
    params: query
  })
}

// 查询任务提醒规则列表
export function beLongSave(data) {
  return request({
    url: '/yiqing/yqTask/beLongSave',
    method: 'post',
    data: data
  })
}
